@@ -200,8 +200,18 @@ void ApplicationUpdates::setupTransaction(QApt::Transaction *trans)
             this, SLOT(untrustedPrompt(QStringList)));
     connect(trans, SIGNAL(downloadSpeedChanged(quint64)),
             this, SIGNAL(downloadSpeedChanged(quint64)));
+    connect(trans, SIGNAL(finished(QApt::ExitStatus)),
+            this, SLOT(transactionFinished(QApt::ExitStatus)));
 }
 
+void ApplicationUpdates::transactionFinished(QApt::ExitStatus )
+{
+    m_lastRealProgress = 0;
+    m_appBackend->reload();
+    setProgressing(false);
+}
+
+
 bool ApplicationUpdates::isAllMarked() const
 {
     QApt::PackageList upgradeable = m_aptBackend->upgradeablePackages();
@@ -350,8 +360,6 @@ void ApplicationUpdates::statusChanged(QApt::TransactionStatus status)
             setProgress(100);
             setStatusMessage(i18nc("@info Status information, widget title",
                                         "Finished"));
-            m_lastRealProgress = 0;
-            m_appBackend->reload();
             break;
     }
 }
@@ -443,6 +451,8 @@ void ApplicationUpdates::calculateUpdates()
             AbstractResource* res = m_appBackend->resourceByPackageName(it->name());
             if(!res) //If we couldn't find it by its name, try with
                 res = m_appBackend->resourceByPackageName(QString("%1:%2").arg(it->name()).arg(it->architecture()));
+            if(!res)
+                qWarning() << "Couldn't find the package:" << it->name();
             Q_ASSERT(res);
             m_toUpdate += res;
         }
@@ -451,6 +461,7 @@ void ApplicationUpdates::calculateUpdates()
 
 bool ApplicationUpdates::isMarked(AbstractResource* res) const
 {
+    Q_ASSERT(!res->backend()->isFetching());
     Application* app = qobject_cast<Application*>(res);
     Q_ASSERT(app);
     return app->package()->state() & QApt::Package::ToInstall;
